Crate media

Crate media 

Structs

WindowGLContext
A PlayerGLContext that renders to a window. Note that if the background thread is not started for this context, then it is inactive (returning Unknown values in the trait implementation).

Enums

GLPlayerMsg
GLPlayer thread Message API
GLPlayerMsgForward
These are the messages that the GLPlayer thread will forward to the video player which lives in htmlmediaelement
GlApi
GlContext
NativeDisplay

Traits

PlayerGLContext