fn demux_for(format: OutputFormat) -> &'static strExpand description
Demuxer element that reads the live video intermediate back for the finalize remux.
fn demux_for(format: OutputFormat) -> &'static strDemuxer element that reads the live video intermediate back for the finalize remux.